@@ -2,7 +2,7 @@ traplot1 <- function(x, col=mcmcplotsPalette(nchains), lty=1, style=c("gray", "p
     style <- match.arg(style)
     nchains <- nchain(x)
     xx <- as.vector(time(x))
-    yy <- do.call("cbind", x)
+    yy <- do.call("cbind", as.list(x))
     if (style=="plain"){
         matplot(xx, yy, type="l", col=col, lty=lty, ...)
     }
